﻿using System;
using System.Diagnostics;
using System.IO;

namespace HelloWorldSVRest
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                SmartVault smartVault = new SmartVault();
                Authenticate(smartVault);

                string localFile = GetLocalFile();
                string remoteFolder = GetRemoteFolder(smartVault);

                Console.WriteLine("\nUploading '{0}' to '{1}'", localFile, remoteFolder);
                smartVault.UploadFile(localFile, remoteFolder);
                Console.WriteLine("\nUpload complete");
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }

            Console.WriteLine("\nPress any key to exit");
            Console.ReadKey();
        }

        private static void Authenticate(SmartVault smartVault)
        {
            // Pin-based authentication with manual pin entry
            Console.Write("Enter your email address: ");
            string email = Console.ReadLine();

            Console.Write("Do you have a pin? [y/n]: ");
            string response = Console.ReadLine();

            if (!response.ToLower().StartsWith("y"))
            {
                string url = smartVault.RequestPin(email);
                Process.Start(url);
            }

            Console.Write("Enter your pin: ");
            string pin = Console.ReadLine();

            smartVault.Authenticate(email, pin);
        }

        private static string GetLocalFile()
        {
            Console.Write("\nEnter the path to a file to upload. " +
                "(Hint: drag a file to the console window): ");
            string localFile = Console.ReadLine();

            return localFile.Replace("\"", ""); // Remove quotes, if supplied
        }

        private static string GetRemoteFolder(SmartVault smartVault)
        {
            var rootNode = smartVault.BrowsePath("/nodes/pth");
            string account = rootNode.Message.ChildrenList[0].Name;

            return String.Format("/nodes/pth/{0}/My First Vault/My First folder", account);
        }
    }
}
